@@ -12,6 +12,7 @@
 #' @seealso \code{\link{getProfile}}, \code{\link{searchPeople}}
 #'
 #' @param token Authorization token.
+#' @param partner Indicate whether you belong to the Partnership Program. Values: 0 or 1
 #' 
 #' @return Returns a dataframe of your 1st degree LinkedIn connections.
 #' 
@@ -23,12 +24,22 @@
 #' @export
 
 
-getMyConnections <- function(token)
+getMyConnections <- function(token, partner = 0)
 { 
+  
+  if(partner == 0){
+    stop("This function is no longer available through LinkedIn's open API.  \n
+  If you are a member of the Partnership Program, set the 'partner' input of this function equal to 1 (default: 0).")
+  }
+  
   # returns default fields
   base_url <- "http://api.linkedin.com/v1/people/~/connections"
   query <- GET(base_url, config(token = token))
   q.content <- content(query) 
+  xml <- xmlTreeParse(q.content, useInternalNodes=TRUE)
+  if(!is.na(xml[["number(//error/status)"]]==404)){
+    stop(xml[["string(//error/message)"]])
+  }
   q.df <- connectionsToDF(q.content)
   return(q.df)
 }
